Module: Fastlane::Hexsign
- Defined in:
- lib/fastlane/plugin/hexsign.rb,
lib/fastlane/plugin/hexsign/version.rb
Constant Summary collapse
- VERSION =
"0.2.0"
Class Method Summary collapse
-
.all_classes ⇒ Object
Auto-load every action and helper in this gem so Fastlane can discover them.
Class Method Details
.all_classes ⇒ Object
Auto-load every action and helper in this gem so Fastlane can discover them.
8 9 10 |
# File 'lib/fastlane/plugin/hexsign.rb', line 8 def self.all_classes Dir[File.("hexsign/**/*.rb", __dir__)] end |